@@ -13,7 +13,9 @@
 #include <QtCore/QObject>
 #include <QtCore/QDate>
 #include <Snapd/WrappedObject>
+#include <Snapd/Enums>
 #include <Snapd/App>
+#include <Snapd/Channel>
 #include <Snapd/Price>
 #include <Snapd/Screenshot>
 
@@ -23,7 +25,8 @@ class Q_DECL_EXPORT QSnapdSnap : public QSnapdWrappedObject
 
     Q_PROPERTY(int appCount READ appCount)
     Q_PROPERTY(QString channel READ channel)
-    Q_PROPERTY(QSnapdConfinement confinement READ confinement)
+    Q_PROPERTY(int channelCount READ channelCount)
+    Q_PROPERTY(QSnapdEnums::SnapConfinement confinement READ confinement)
     Q_PROPERTY(QString contact READ contact)
     Q_PROPERTY(QString description READ description)
     Q_PROPERTY(QString developer READ developer)
@@ -39,50 +42,25 @@ class Q_DECL_EXPORT QSnapdSnap : public QSnapdWrappedObject
     Q_PROPERTY(int priceCount READ priceCount)
     Q_PROPERTY(bool isPrivate READ isPrivate)
     Q_PROPERTY(QString revision READ revision)
-    Q_PROPERTY(QSnapdSnapType snapType READ snapType)
-    Q_PROPERTY(QSnapdSnapStatus status READ status)
+    Q_PROPERTY(QSnapdEnums::SnapType snapType READ snapType)
+    Q_PROPERTY(QSnapdEnums::SnapStatus status READ status)
     Q_PROPERTY(QString summary READ summary)
     Q_PROPERTY(QString title READ title)
     Q_PROPERTY(QString trackingChannel READ trackingChannel)
+    Q_PROPERTY(QStringList tracks READ tracks)
     Q_PROPERTY(bool trymode READ trymode)
     Q_PROPERTY(QString version READ version)
 
 public:
-    enum QSnapdConfinement
-    {
-        ConfinementUnknown,
-        Strict,
-        Devmode,
-        Classic
-    };
-    Q_ENUM(QSnapdConfinement)
-
-    enum QSnapdSnapType
-    {
-        TypeUnknown,
-        App,
-        Kernel,
-        Gadget,
-        OperatingSystem
-    };
-    Q_ENUM(QSnapdSnapType)
-
-    enum QSnapdSnapStatus
-    {
-        StatusUnknown,
-        Available,
-        Priced,
-        Installed,
-        Active
-    };
-    Q_ENUM(QSnapdSnapStatus)
-
     explicit QSnapdSnap (void* snapd_object, QObject* parent = 0);
 
     int appCount () const;
     Q_INVOKABLE QSnapdApp *app (int) const;
     QString channel () const;
-    QSnapdConfinement confinement () const;
+    int channelCount () const;
+    Q_INVOKABLE QSnapdChannel *channel (int) const;
+    Q_INVOKABLE QSnapdChannel *matchChannel (const QString&) const;
+    QSnapdEnums::SnapConfinement confinement () const;
     QString contact () const;
     QString description () const;
     QString developer () const;
@@ -101,11 +79,12 @@ public:
     QString revision () const;
     int screenshotCount () const;
     Q_INVOKABLE QSnapdScreenshot *screenshot (int) const;
-    QSnapdSnapType snapType () const;
-    QSnapdSnapStatus status () const;
+    QSnapdEnums::SnapType snapType () const;
+    QSnapdEnums::SnapStatus status () const;
     QString summary () const;
     QString title () const;
     QString trackingChannel () const;
+    QStringList tracks () const;
     bool trymode () const;
     QString version () const;
 };
