@@ -86,6 +86,18 @@ QSnapdLoginRequest *QSnapdClient::login (const QString& username, const QString&
     return new QSnapdLoginRequest (d->client, username, password, otp);
 }
 
+void QSnapdClient::setSocketPath (const QString &socketPath)
+{
+    Q_D(QSnapdClient);
+    snapd_client_set_socket_path (d->client, socketPath.isNull () ? NULL : socketPath.toStdString ().c_str ());
+}
+
+QString QSnapdClient::socketPath () const
+{
+    Q_D(const QSnapdClient);
+    return snapd_client_get_socket_path (d->client);
+}
+
 void QSnapdClient::setUserAgent (const QString &userAgent)
 {
     Q_D(QSnapdClient);
@@ -230,13 +242,13 @@ QSnapdFindRequest::~QSnapdFindRequest ()
 QSnapdFindRequest *QSnapdClient::find (FindFlags flags)
 {
     Q_D(QSnapdClient);
-    return new QSnapdFindRequest (flags, QString (), NULL, d->client);
+    return new QSnapdFindRequest (flags, NULL, NULL, d->client);
 }
 
 QSnapdFindRequest *QSnapdClient::find (FindFlags flags, const QString& name)
 {
     Q_D(QSnapdClient);
-    return new QSnapdFindRequest (flags, QString (), name, d->client);
+    return new QSnapdFindRequest (flags, NULL, name, d->client);
 }
 
 QSnapdFindRequest *QSnapdClient::findSection (FindFlags flags, const QString &section, const QString& name)
@@ -470,29 +482,17 @@ QSnapdConnectRequest::QSnapdConnectRequest (void *snapd_client, QObject *parent)
 
 void QSnapdConnectRequest::runSync ()
 {
-    g_autoptr(GError) error = NULL;
-    snapd_client_connect_sync (SNAPD_CLIENT (getClient ()), G_CANCELLABLE (getCancellable ()), &error);
-    finish (error);
+    finish (NULL);
 }
 
 void QSnapdConnectRequest::handleResult (void *object, void *result)
 {
-    g_autoptr(GError) error = NULL;
-
-    snapd_client_connect_finish (SNAPD_CLIENT (object), G_ASYNC_RESULT (result), &error);
-
-    finish (error);
-}
-
-static void connect_ready_cb (GObject *object, GAsyncResult *result, gpointer data)
-{
-    QSnapdGetSystemInformationRequest *request = static_cast<QSnapdGetSystemInformationRequest*>(data);
-    request->handleResult (object, result);
+    finish (NULL);
 }
 
 void QSnapdConnectRequest::runAsync ()
 {
-    snapd_client_connect_async (SNAPD_CLIENT (getClient ()), G_CANCELLABLE (getCancellable ()), connect_ready_cb, (gpointer) this);
+    handleResult (NULL, NULL);
 }
 
 QSnapdLoginRequest::QSnapdLoginRequest (void *snapd_client, const QString& username, const QString& password, const QString& otp, QObject *parent) :
@@ -992,7 +992,7 @@ void QSnapdFindRequest::runSync ()
     Q_D(QSnapdFindRequest);
     g_autoptr(GError) error = NULL;
     g_autofree gchar *suggested_currency = NULL;
-    d->snaps = snapd_client_find_section_sync (SNAPD_CLIENT (getClient ()), convertFindFlags (d->flags), d->section.toStdString().c_str (), d->name.toStdString ().c_str (), &suggested_currency, G_CANCELLABLE (getCancellable ()), &error);
+    d->snaps = snapd_client_find_section_sync (SNAPD_CLIENT (getClient ()), convertFindFlags (d->flags), d->section.isNull () ? NULL : d->section.toStdString().c_str (), d->name.isNull () ? NULL : d->name.toStdString ().c_str (), &suggested_currency, G_CANCELLABLE (getCancellable ()), &error);
     d->suggestedCurrency = suggested_currency;
     finish (error);
 }
@@ -1020,7 +1020,7 @@ static void find_ready_cb (GObject *object, GAsyncResult *result, gpointer data)
 void QSnapdFindRequest::runAsync ()
 {
     Q_D(QSnapdFindRequest);
-    snapd_client_find_section_async (SNAPD_CLIENT (getClient ()), convertFindFlags (d->flags), d->section.toStdString ().c_str (), d->name.toStdString ().c_str (), G_CANCELLABLE (getCancellable ()), find_ready_cb, (gpointer) this);
+    snapd_client_find_section_async (SNAPD_CLIENT (getClient ()), convertFindFlags (d->flags), d->section.isNull () ? NULL : d->section.toStdString ().c_str (), d->name.isNull () ? NULL : d->name.toStdString ().c_str (), G_CANCELLABLE (getCancellable ()), find_ready_cb, (gpointer) this);
 }
 
 int QSnapdFindRequest::snapCount () const
@@ -1141,9 +1141,9 @@ void QSnapdInstallRequest::handleResult (void *object, void *result)
     g_autoptr(GError) error = NULL;
 
     if (d->wrapper != NULL)
-        snapd_client_install2_finish (SNAPD_CLIENT (object), G_ASYNC_RESULT (result), &error);
-    else
         snapd_client_install_stream_finish (SNAPD_CLIENT (object), G_ASYNC_RESULT (result), &error);
+    else
+        snapd_client_install2_finish (SNAPD_CLIENT (object), G_ASYNC_RESULT (result), &error);
 
     finish (error);
 }
