@@ -64,6 +64,7 @@ typedef struct
     gchar *summary;
     gchar *title;
     gchar *tracking_channel;
+    GList *tracks;
     gboolean trymode;
     gchar *type;
     gchar *version;
@@ -74,6 +75,8 @@ typedef struct
     gboolean dangerous;
     gchar *snap_data;
     gchar *snap_path;
+    gchar *error;
+    gboolean restart_required;
 } MockSnap;
 
 typedef struct
@@ -90,6 +93,23 @@ typedef struct
     gchar *status;
 } MockAlias;
 
+typedef struct
+{
+    gchar *name;
+    GList *channels;
+} MockTrack;
+
+typedef struct
+{
+    gchar *risk;
+    gchar *branch;
+    gchar *confinement;
+    gchar *epoch;
+    gchar *revision;
+    int size;
+    gchar *version;
+} MockChannel;
+
 typedef struct
 {
     gdouble amount;
@@ -126,11 +146,14 @@ struct _MockSlot
 
 MockSnapd      *mock_snapd_new                    (void);
 
-GSocket        *mock_snapd_get_client_socket      (MockSnapd     *snapd);
+const gchar    *mock_snapd_get_socket_path        (MockSnapd     *snapd);
 
 void            mock_snapd_set_close_on_request   (MockSnapd     *snapd,
                                                    gboolean       close_on_request);
 
+gboolean        mock_snapd_start                  (MockSnapd     *snapd,
+                                                   GError       **error);
+
 void            mock_snapd_stop                   (MockSnapd     *snapd);
 
 void            mock_snapd_set_confinement        (MockSnapd     *snapd,
@@ -195,6 +218,25 @@ void            mock_app_set_desktop_file         (MockApp       *app,
 void            mock_snap_set_channel             (MockSnap      *snap,
                                                    const gchar   *channel);
 
+MockTrack      *mock_snap_add_track               (MockSnap      *snap,
+                                                   const gchar   *name);
+
+MockChannel    *mock_track_add_channel            (MockTrack     *track,
+                                                   const gchar   *risk,
+                                                   const gchar   *branch);
+
+void            mock_channel_set_confinement      (MockChannel  *channel,
+                                                   const gchar   *confinement);
+
+void            mock_channel_set_epoch            (MockChannel  *channel,
+                                                   const gchar   *epoch);
+
+void            mock_channel_set_revision         (MockChannel  *channel,
+                                                   const gchar   *revision);
+
+void            mock_channel_set_version          (MockChannel  *channel,
+                                                   const gchar   *version);
+
 void            mock_snap_set_confinement         (MockSnap      *snap,
                                                    const gchar   *confinement);
 
@@ -207,6 +249,9 @@ void            mock_snap_set_description         (MockSnap      *snap,
 void            mock_snap_set_developer           (MockSnap      *snap,
                                                    const gchar   *developer);
 
+void            mock_snap_set_error               (MockSnap      *snap,
+                                                   const gchar   *error);
+
 void            mock_snap_set_icon                (MockSnap      *snap,
                                                    const gchar   *icon);
 
